@@ -9,7 +9,7 @@ from pathlib import Path
 from typing import override
 
 import aiohttp
-import ripgrepy
+import ripgrepy  # pyright: ignore[reportMissingTypeStubs]
 from kosong.tooling import CallableTool2, ToolError, ToolOk, ToolReturnType
 from pydantic import BaseModel, Field
 
@@ -220,7 +220,7 @@ async def _ensure_rg_path() -> str:
 
 class Grep(CallableTool2[Params]):
     name: str = "Grep"
-    description: str = (Path(__file__).parent / "grep.md").read_text()
+    description: str = (Path(__file__).parent / "grep.md").read_text(encoding="utf-8")
     params: type[Params] = Params
 
     @override
