@@ -1,12 +1,13 @@
 from pathlib import Path
-from typing import override
+from typing import Any, override
 
 from kosong.tooling import CallableTool2, ToolReturnType
 from pydantic import BaseModel, Field, ValidationError
 
-import kimi_cli
 from kimi_cli.config import Config
+from kimi_cli.constant import USER_AGENT
 from kimi_cli.soul.toolset import get_current_tool_call_or_none
+from kimi_cli.tools import SkipThisTool
 from kimi_cli.tools.utils import ToolResultBuilder, load_desc
 from kimi_cli.utils.aiohttp import new_client_session
 
@@ -39,14 +40,13 @@ class SearchWeb(CallableTool2[Params]):
     description: str = load_desc(Path(__file__).parent / "search.md", {})
     params: type[Params] = Params
 
-    def __init__(self, config: Config, **kwargs):
+    def __init__(self, config: Config, **kwargs: Any):
         super().__init__(**kwargs)
-        if config.services.moonshot_search is not None:
-            self._base_url = config.services.moonshot_search.base_url
-            self._api_key = config.services.moonshot_search.api_key.get_secret_value()
-        else:
-            self._base_url = ""
-            self._api_key = ""
+        if config.services.moonshot_search is None:
+            raise SkipThisTool()
+        self._base_url = config.services.moonshot_search.base_url
+        self._api_key = config.services.moonshot_search.api_key.get_secret_value()
+        self._custom_headers = config.services.moonshot_search.custom_headers or {}
 
     @override
     async def __call__(self, params: Params) -> ToolReturnType:
@@ -66,9 +66,10 @@ class SearchWeb(CallableTool2[Params]):
             session.post(
                 self._base_url,
                 headers={
-                    "User-Agent": kimi_cli.USER_AGENT,
+                    "User-Agent": USER_AGENT,
                     "Authorization": f"Bearer {self._api_key}",
                     "X-Msh-Tool-Call-Id": tool_call.id,
+                    **self._custom_headers,
                 },
                 json={
                     "text_query": params.query,
