@@ -12,18 +12,17 @@ from kosong.base.message import (
 from kosong.chat_provider import ChatProviderError
 from kosong.tooling import ToolError, ToolOk, ToolResult
 
-from kimi_cli.soul import LLMNotSet, MaxStepsReached, Soul
-from kimi_cli.soul.wire import (
+from kimi_cli.soul import LLMNotSet, MaxStepsReached, RunCancelled, Soul, run_soul
+from kimi_cli.tools import extract_subtitle
+from kimi_cli.utils.logging import logger
+from kimi_cli.wire import WireUISide
+from kimi_cli.wire.message import (
     ApprovalRequest,
     ApprovalResponse,
     StatusUpdate,
     StepBegin,
     StepInterrupted,
-    Wire,
 )
-from kimi_cli.tools import extract_subtitle
-from kimi_cli.ui import RunCancelled, run_soul
-from kimi_cli.utils.logging import logger
 
 
 class _ToolCallState:
@@ -64,7 +63,7 @@ class _RunState:
         self.cancel_event = asyncio.Event()
 
 
-class ACPAgentImpl:
+class ACPAgent:
     """Implementation of the ACP Agent protocol."""
 
     def __init__(self, soul: Soul, connection: acp.AgentSideConnection):
@@ -172,34 +171,30 @@ class ACPAgentImpl:
             logger.info("Cancelling running prompt")
             self.run_state.cancel_event.set()
 
-    async def _stream_events(self, wire: Wire):
-        try:
-            # expect a StepBegin
-            assert isinstance(await wire.receive(), StepBegin)
+    async def _stream_events(self, wire: WireUISide):
+        assert isinstance(await wire.receive(), StepBegin)
 
-            while True:
-                msg = await wire.receive()
+        while True:
+            msg = await wire.receive()
 
-                if isinstance(msg, TextPart):
-                    await self._send_text(msg.text)
-                elif isinstance(msg, ContentPart):
-                    logger.warning("Unsupported content part: {part}", part=msg)
-                    await self._send_text(f"[{msg.__class__.__name__}]")
-                elif isinstance(msg, ToolCall):
-                    await self._send_tool_call(msg)
-                elif isinstance(msg, ToolCallPart):
-                    await self._send_tool_call_part(msg)
-                elif isinstance(msg, ToolResult):
-                    await self._send_tool_result(msg)
-                elif isinstance(msg, ApprovalRequest):
-                    await self._handle_approval_request(msg)
-                elif isinstance(msg, StatusUpdate):
-                    # TODO: stream status if needed
-                    pass
-                elif isinstance(msg, StepInterrupted):
-                    break
-        except asyncio.QueueShutDown:
-            logger.debug("Event stream loop shutting down")
+            if isinstance(msg, TextPart):
+                await self._send_text(msg.text)
+            elif isinstance(msg, ContentPart):
+                logger.warning("Unsupported content part: {part}", part=msg)
+                await self._send_text(f"[{msg.__class__.__name__}]")
+            elif isinstance(msg, ToolCall):
+                await self._send_tool_call(msg)
+            elif isinstance(msg, ToolCallPart):
+                await self._send_tool_call_part(msg)
+            elif isinstance(msg, ToolResult):
+                await self._send_tool_result(msg)
+            elif isinstance(msg, ApprovalRequest):
+                await self._handle_approval_request(msg)
+            elif isinstance(msg, StatusUpdate):
+                # TODO: stream status if needed
+                pass
+            elif isinstance(msg, StepInterrupted):
+                break
 
     async def _send_text(self, text: str):
         """Send text chunk to client."""
@@ -322,7 +317,7 @@ class ACPAgentImpl:
         # Create permission request with options
         permission_request = acp.RequestPermissionRequest(
             sessionId=self.session_id,
-            toolCall=acp.schema.ToolCallUpdate(
+            toolCall=acp.schema.ToolCall(
                 toolCallId=state.acp_tool_call_id,
                 content=[
                     acp.schema.ContentToolCallContent(
@@ -428,7 +423,7 @@ class ACPServer:
 
         # Create connection - the library handles all JSON-RPC details!
         _ = acp.AgentSideConnection(
-            lambda conn: ACPAgentImpl(self.soul, conn),
+            lambda conn: ACPAgent(self.soul, conn),
             writer,
             reader,
         )
