@@ -1,19 +1,25 @@
 import asyncio
+import base64
 import contextlib
 import getpass
 import json
 import os
 import re
+import sys
 import time
 from collections.abc import Callable
 from datetime import datetime
 from enum import Enum
 from hashlib import md5
+from io import BytesIO
 from pathlib import Path
 from typing import override
 
+from kosong.base.message import ContentPart, ImageURLPart, TextPart
+from PIL import Image, ImageGrab
 from prompt_toolkit import PromptSession
 from prompt_toolkit.application.current import get_app_or_none
+from prompt_toolkit.clipboard.pyperclip import PyperclipClipboard
 from prompt_toolkit.completion import (
     Completer,
     Completion,
@@ -33,7 +39,11 @@ from pydantic import BaseModel, ValidationError
 from kimi_cli.share import get_share_dir
 from kimi_cli.soul import StatusSnapshot
 from kimi_cli.ui.shell.metacmd import get_meta_commands
+from kimi_cli.utils.clipboard import is_clipboard_available
 from kimi_cli.utils.logging import logger
+from kimi_cli.utils.string import random_string
+
+PROMPT_SYMBOL = "✨"
 
 
 class MetaCommandCompleter(Completer):
@@ -360,6 +370,9 @@ class PromptMode(Enum):
 class UserInput(BaseModel):
     mode: PromptMode
     command: str
+    """The plain text representation of the user input."""
+    content: list[ContentPart]
+    """The rich content parts."""
 
     def __str__(self) -> str:
         return self.command
@@ -377,6 +390,11 @@ def toast(message: str, duration: float = 5.0) -> None:
     _toast_queue.put_nowait((message, duration))
 
 
+_ATTACHMENT_PLACEHOLDER_RE = re.compile(
+    r"\[(?P<type>image):(?P<id>[a-zA-Z0-9_\-\.]+)(?:,(?P<width>\d+)x(?P<height>\d+))?\]"
+)
+
+
 class CustomPromptSession:
     def __init__(self, status_provider: Callable[[], StatusSnapshot]):
         history_dir = get_share_dir() / "user-history"
@@ -386,6 +404,8 @@ class CustomPromptSession:
         self._status_provider = status_provider
         self._last_history_content: str | None = None
         self._mode: PromptMode = PromptMode.AGENT
+        self._attachment_parts: dict[str, ContentPart] = {}
+        """Mapping from attachment id to ContentPart."""
 
         history_entries = _load_history_entries(self._history_file)
         history = InMemoryHistory()
@@ -407,6 +427,7 @@ class CustomPromptSession:
 
         # Build key bindings
         _kb = KeyBindings()
+        shortcut_hints: list[str] = []
 
         @_kb.add("enter", filter=has_completions)
         def _accept_completion(event: KeyPressEvent) -> None:
@@ -419,20 +440,46 @@ class CustomPromptSession:
                     completion = buff.complete_state.completions[0]
                 buff.apply_completion(completion)
 
-        @_kb.add("c-k", eager=True)
-        def _toggle_mode(event: KeyPressEvent) -> None:
+        @_kb.add("c-x", eager=True)
+        def _switch_mode(event: KeyPressEvent) -> None:
             self._mode = self._mode.toggle()
             # Apply mode-specific settings
             self._apply_mode(event)
             # Redraw UI
             event.app.invalidate()
 
+        shortcut_hints.append("ctrl-x: switch mode")
+
+        @_kb.add("escape", "enter", eager=True)
+        @_kb.add("c-j", eager=True)
+        def _insert_newline(event: KeyPressEvent) -> None:
+            """Insert a newline when Alt-Enter or Ctrl-J is pressed."""
+            event.current_buffer.insert_text("\n")
+
+        shortcut_hints.append("ctrl-j: newline")
+
+        if is_clipboard_available():
+
+            @_kb.add("c-v", eager=True)
+            def _paste(event: KeyPressEvent) -> None:
+                if self._try_paste_image(event):
+                    return
+                clipboard_data = event.app.clipboard.get_data()
+                event.current_buffer.paste_clipboard_data(clipboard_data)
+
+            shortcut_hints.append("ctrl-v: paste")
+            clipboard = PyperclipClipboard()
+        else:
+            clipboard = None
+
+        self._shortcut_hints = shortcut_hints
         self._session = PromptSession(
             message=self._render_message,
-            prompt_continuation=FormattedText([("fg:#4d4d4d", "... ")]),
+            # prompt_continuation=FormattedText([("fg:#4d4d4d", "... ")]),
             completer=self._agent_mode_completer,
             complete_while_typing=True,
             key_bindings=_kb,
+            clipboard=clipboard,
             history=history,
             bottom_toolbar=self._render_bottom_toolbar,
         )
@@ -442,7 +489,7 @@ class CustomPromptSession:
         self._current_toast_duration: float = 0.0
 
     def _render_message(self) -> FormattedText:
-        symbol = "✨" if self._mode == PromptMode.AGENT else "$"
+        symbol = PROMPT_SYMBOL if self._mode == PromptMode.AGENT else "$"
         return FormattedText([("bold", f"{getpass.getuser()}{symbol} ")])
 
     def _apply_mode(self, event: KeyPressEvent | None = None) -> None:
@@ -495,12 +542,76 @@ class CustomPromptSession:
         if self._status_refresh_task is not None and not self._status_refresh_task.done():
             self._status_refresh_task.cancel()
         self._status_refresh_task = None
+        self._attachment_parts.clear()
+
+    def _try_paste_image(self, event: KeyPressEvent) -> bool:
+        """Try to paste an image from the clipboard. Return True if successful."""
+        # Try get image from clipboard
+        image = ImageGrab.grabclipboard()
+        if isinstance(image, list):
+            for item in image:
+                try:
+                    with Image.open(item) as img:
+                        image = img.copy()
+                    break
+                except Exception:
+                    continue
+            else:
+                image = None
+
+        if image is None:
+            return False
+
+        attachment_id = f"{random_string(8)}.png"
+        png_bytes = BytesIO()
+        image.save(png_bytes, format="PNG")
+        png_base64 = base64.b64encode(png_bytes.getvalue()).decode("ascii")
+        image_part = ImageURLPart(
+            image_url=ImageURLPart.ImageURL(
+                url=f"data:image/png;base64,{png_base64}", id=attachment_id
+            )
+        )
+        self._attachment_parts[attachment_id] = image_part
+        logger.debug(
+            "Pasted image from clipboard: {attachment_id}, {image_size}",
+            attachment_id=attachment_id,
+            image_size=image.size,
+        )
+
+        placeholder = f"[image:{attachment_id},{image.width}x{image.height}]"
+        event.current_buffer.insert_text(placeholder)
+        event.app.invalidate()
+        return True
 
     async def prompt(self) -> UserInput:
         with patch_stdout():
             command = str(await self._session.prompt_async()).strip()
+            command = command.replace("\x00", "")  # just in case null bytes are somehow inserted
         self._append_history_entry(command)
-        return UserInput(mode=self._mode, command=command)
+
+        # Parse rich content parts
+        content: list[ContentPart] = []
+        remaining_command = command
+        while match := _ATTACHMENT_PLACEHOLDER_RE.search(remaining_command):
+            start, end = match.span()
+            if start > 0:
+                content.append(TextPart(text=remaining_command[:start]))
+            attachment_id = match.group("id")
+            part = self._attachment_parts.get(attachment_id)
+            if part is not None:
+                content.append(part)
+            else:
+                logger.warning(
+                    "Attachment placeholder found but no matching attachment part: {placeholder}",
+                    placeholder=match.group(0),
+                )
+                content.append(TextPart(text=match.group(0)))
+            remaining_command = remaining_command[end:]
+
+        if remaining_command.strip():
+            content.append(TextPart(text=remaining_command.strip()))
+
+        return UserInput(mode=self._mode, content=content, command=command)
 
     def _append_history_entry(self, text: str) -> None:
         entry = _HistoryEntry(content=text.strip())
@@ -549,7 +660,7 @@ class CustomPromptSession:
                 self._current_toast = None
         else:
             shortcuts = [
-                "ctrl-k: toggle mode",
+                *self._shortcut_hints,
                 "ctrl-d: exit",
             ]
             for shortcut in shortcuts:
@@ -572,3 +683,107 @@ class CustomPromptSession:
     def _format_status(status: StatusSnapshot) -> str:
         bounded = max(0.0, min(status.context_usage, 1.0))
         return f"context: {bounded:.1%}"
+
+
+def ensure_new_line() -> None:
+    """Ensure the next prompt starts at column 0 regardless of prior command output."""
+
+    if not sys.stdout.isatty() or not sys.stdin.isatty():
+        return
+
+    needs_break = True
+    if sys.platform == "win32":
+        column = _cursor_column_windows()
+        needs_break = column not in (None, 0)
+    else:
+        column = _cursor_column_unix()
+        needs_break = column not in (None, 1)
+
+    if needs_break:
+        _write_newline()
+
+
+def _cursor_column_unix() -> int | None:
+    assert sys.platform != "win32"
+
+    import select
+    import termios
+    import tty
+
+    _CURSOR_QUERY = "\x1b[6n"
+    _CURSOR_POSITION_RE = re.compile(r"\x1b\[(\d+);(\d+)R")
+
+    fd = sys.stdin.fileno()
+    oldterm = termios.tcgetattr(fd)
+
+    try:
+        tty.setcbreak(fd)
+        sys.stdout.write(_CURSOR_QUERY)
+        sys.stdout.flush()
+
+        response = ""
+        deadline = time.monotonic() + 0.2
+        while time.monotonic() < deadline:
+            timeout = max(0.01, deadline - time.monotonic())
+            ready, _, _ = select.select([sys.stdin], [], [], timeout)
+            if not ready:
+                continue
+            try:
+                chunk = os.read(fd, 32)
+            except OSError:
+                break
+            if not chunk:
+                break
+            response += chunk.decode(errors="ignore")
+            match = _CURSOR_POSITION_RE.search(response)
+            if match:
+                return int(match.group(2))
+    finally:
+        termios.tcsetattr(fd, termios.TCSADRAIN, oldterm)
+
+    return None
+
+
+def _cursor_column_windows() -> int | None:
+    assert sys.platform == "win32"
+
+    import ctypes
+    from ctypes import wintypes
+
+    kernel32 = ctypes.windll.kernel32
+    _STD_OUTPUT_HANDLE = -11  # Windows API constant for standard output handle
+    handle = kernel32.GetStdHandle(_STD_OUTPUT_HANDLE)
+    invalid_handle_value = ctypes.c_void_p(-1).value
+    if handle in (0, invalid_handle_value):
+        return None
+
+    class COORD(ctypes.Structure):
+        _fields_ = [("X", wintypes.SHORT), ("Y", wintypes.SHORT)]
+
+    class SMALL_RECT(ctypes.Structure):
+        _fields_ = [
+            ("Left", wintypes.SHORT),
+            ("Top", wintypes.SHORT),
+            ("Right", wintypes.SHORT),
+            ("Bottom", wintypes.SHORT),
+        ]
+
+    class CONSOLE_SCREEN_BUFFER_INFO(ctypes.Structure):
+        _fields_ = [
+            ("dwSize", COORD),
+            ("dwCursorPosition", COORD),
+            ("wAttributes", wintypes.WORD),
+            ("srWindow", SMALL_RECT),
+            ("dwMaximumWindowSize", COORD),
+        ]
+
+    csbi = CONSOLE_SCREEN_BUFFER_INFO()
+    if not kernel32.GetConsoleScreenBufferInfo(handle, ctypes.byref(csbi)):
+        return None
+
+    return int(csbi.dwCursorPosition.X)
+
+
+def _write_newline() -> None:
+    sys.stdout.write("\n")
+    sys.stdout.flush()
